@@ -132,14 +132,17 @@ class SagemakerFeatureStore:
         self.athena_queries_prefix_uri = "athena_queries"
 
         # Initialize Redis Connection
-        if redis_host and redis_password and redis_port:
+        if redis_host and redis_port:
             # Store credentials
             self.redis_host = redis_host
             self.redis_port = redis_port
-            self.redis_password = redis_password
+            if redis_password:
+                self.redis_password = redis_password
+            else:
+                self.redis_password = None
 
             # Password needed for Redis Enterprise
-            self.redis_client = self._init_redis(redis_host, redis_password, redis_port)
+            self.redis_client = self._init_redis(redis_host, redis_port, redis_password)
 
     def add_event_time_column_df(
         self,
@@ -256,6 +259,14 @@ class SagemakerFeatureStore:
             feature_definitions=feature_definitions,
         )
 
+        # Set value of enable online store to False if dynamodb not in online store sources list
+        if (
+            "dynamodb" not in online_store_sources
+            and "redis" in online_store_sources
+            and enable_online_store
+        ):
+            enable_online_store_aws = False
+
         # Feature group creation
         feature_group.create(
             s3_uri=(
@@ -264,7 +275,7 @@ class SagemakerFeatureStore:
             record_identifier_name=record_identifier_feature_name,
             event_time_feature_name=event_time_feature_name,
             role_arn=self.role,
-            enable_online_store=enable_online_store,
+            enable_online_store=enable_online_store_aws,
         )
 
         print(f'Creating "{feature_group_name}" Feature Group..')
@@ -275,9 +286,6 @@ class SagemakerFeatureStore:
 
         if not enable_online_store:
             online_store_sources = []
-        else:
-            if "dynamodb" not in online_store_sources:
-                online_store_sources.append("dynamodb")
 
         config_data = {
             "feature_group_name": feature_group_name,
@@ -551,9 +559,7 @@ class SagemakerFeatureStore:
                 redis_client = Redis(
                     host=redis_config["redis_host"],
                     port=redis_config["redis_port"],
-                    password=redis_config["redis_password"]
-                    if redis_config["redis_password"]
-                    else None,
+                    password=redis_config["redis_password"],
                     decode_responses=True,
                 )
                 is_redis = True
@@ -669,8 +675,8 @@ class SagemakerFeatureStore:
         None
         """
         # Input data limits
-        if len(data) > 100:
-            raise Exception("Batch input data only limited to <=100 rows.")
+        # if len(data) > 100:
+        #     raise Exception("Batch input data only limited to <=100 rows.")
 
         # Retrieve feature group registry
         fg, fg_config = self.get_feature_group(feature_group_name)
@@ -974,7 +980,9 @@ class SagemakerFeatureStore:
         if status == "DeleteFailed":
             raise RuntimeError(f"Failed to delete feature group {feature_group.name}")
 
-    def _init_redis(self, redis_host: str, redis_password: str, redis_port: int):
+    def _init_redis(
+        self, redis_host: str, redis_port: int, redis_password: Union[str, None] = None
+    ):
         """
         Initializes a Redis connection
 
